@@ -22,21 +22,20 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ksld
 #include <config-kscreenlocker.h>
 // Wayland
-#include <wayland-server.h>
 #include <wayland-ksld-server-protocol.h>
+#include <wayland-server.h>
 // KWayland
 #include <KWayland/Server/display.h>
 // Qt
 #include <QDBusConnection>
 // system
-#include <unistd.h>
 #include <fcntl.h>
-#include <sys/types.h>
 #include <sys/socket.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 namespace ScreenLocker
 {
-
 static const QString s_plasmaShellService = QStringLiteral("org.kde.plasmashell");
 static const QString s_osdServicePath = QStringLiteral("/org/kde/osdService");
 static const QString s_osdServiceInterface = QStringLiteral("org.kde.osdService");
@@ -45,16 +44,10 @@ WaylandServer::WaylandServer(QObject *parent)
     : QObject(parent)
 {
     // connect to osd service
-    QDBusConnection::sessionBus().connect(s_plasmaShellService,
-                                          s_osdServicePath,
-                                          s_osdServiceInterface,
-                                          QStringLiteral("osdProgress"),
-                                          this, SLOT(osdProgress(QString,int,QString)));
-    QDBusConnection::sessionBus().connect(s_plasmaShellService,
-                                          s_osdServicePath,
-                                          s_osdServiceInterface,
-                                          QStringLiteral("osdText"),
-                                          this, SLOT(osdText(QString,QString)));
+    QDBusConnection::sessionBus()
+        .connect(s_plasmaShellService, s_osdServicePath, s_osdServiceInterface, QStringLiteral("osdProgress"), this, SLOT(osdProgress(QString, int, QString)));
+    QDBusConnection::sessionBus()
+        .connect(s_plasmaShellService, s_osdServicePath, s_osdServiceInterface, QStringLiteral("osdText"), this, SLOT(osdText(QString, QString)));
     connect(PowerManagement::instance(), &PowerManagement::canSuspendChanged, this, &WaylandServer::sendCanSuspend);
     connect(PowerManagement::instance(), &PowerManagement::canHibernateChanged, this, &WaylandServer::sendCanHibernate);
 }
@@ -87,7 +80,9 @@ int WaylandServer::start()
         close(socketPair[1]);
         return -1;
     }
-    connect(m_allowedClient, &KWayland::Server::ClientConnection::disconnected, this, [this] { m_allowedClient = nullptr; });
+    connect(m_allowedClient, &KWayland::Server::ClientConnection::disconnected, this, [this] {
+        m_allowedClient = nullptr;
+    });
     m_interface = wl_global_create(*m_display.data(), &org_kde_ksld_interface, 3, this, bind);
     return socketPair[1];
 }
@@ -107,7 +102,7 @@ void WaylandServer::stop()
 
 void WaylandServer::bind(wl_client *client, void *data, uint32_t version, uint32_t id)
 {
-    auto s = reinterpret_cast<WaylandServer*>(data);
+    auto s = reinterpret_cast<WaylandServer *>(data);
     if (client != s->m_allowedClient->client()) {
         // a proper error would be better
         wl_client_post_no_memory(client);
@@ -122,7 +117,7 @@ void WaylandServer::bind(wl_client *client, void *data, uint32_t version, uint32
     static const struct org_kde_ksld_interface s_interface = {
         x11WindowCallback,
         suspendSystemCallback,
-        hibernateSystemCallback
+        hibernateSystemCallback,
     };
     wl_resource_set_implementation(r, &s_interface, s, unbind);
     s->addResource(r);
@@ -133,16 +128,16 @@ void WaylandServer::bind(wl_client *client, void *data, uint32_t version, uint32
 
 void WaylandServer::unbind(wl_resource *resource)
 {
-    reinterpret_cast<WaylandServer*>(wl_resource_get_user_data(resource))->removeResource(resource);
+    reinterpret_cast<WaylandServer *>(wl_resource_get_user_data(resource))->removeResource(resource);
 }
 
 void WaylandServer::x11WindowCallback(wl_client *client, wl_resource *resource, uint32_t id)
 {
-    auto s = reinterpret_cast<WaylandServer*>(wl_resource_get_user_data(resource));
+    auto s = reinterpret_cast<WaylandServer *>(wl_resource_get_user_data(resource));
     if (s->m_allowedClient->client() != client) {
         return;
     }
-    emit s->x11WindowAdded(id);
+    Q_EMIT s->x11WindowAdded(id);
 }
 
 void WaylandServer::suspendSystemCallback(wl_client *client, wl_resource *resource)
@@ -174,7 +169,7 @@ void WaylandServer::osdProgress(const QString &icon, int percent, const QString
     if (!m_allowedClient) {
         return;
     }
-    Q_FOREACH (auto r, m_resources) {
+    for (auto r : qAsConst(m_resources)) {
         if (wl_resource_get_version(r) < ORG_KDE_KSLD_OSDPROGRESS_SINCE_VERSION) {
             continue;
         }
@@ -188,7 +183,7 @@ void WaylandServer::osdText(const QString &icon, const QString &additionalText)
     if (!m_allowedClient) {
         return;
     }
-    Q_FOREACH (auto r, m_resources) {
+    for (auto r : qAsConst(m_resources)) {
         if (wl_resource_get_version(r) < ORG_KDE_KSLD_OSDTEXT_SINCE_VERSION) {
             continue;
         }
@@ -202,7 +197,7 @@ void WaylandServer::sendCanSuspend()
     if (!m_allowedClient) {
         return;
     }
-    Q_FOREACH (auto r, m_resources) {
+    for (auto r : qAsConst(m_resources)) {
         if (wl_resource_get_version(r) < ORG_KDE_KSLD_CANSUSPENDSYSTEM_SINCE_VERSION) {
             continue;
         }
@@ -216,7 +211,7 @@ void WaylandServer::sendCanHibernate()
     if (!m_allowedClient) {
         return;
     }
-    Q_FOREACH (auto r, m_resources) {
+    for (auto r : qAsConst(m_resources)) {
         if (wl_resource_get_version(r) < ORG_KDE_KSLD_CANHIBERNATESYSTEM_SINCE_VERSION) {
             continue;
         }
